package com.muyu.kvt.controller;

import java.sql.SQLException;
import java.util.List;


import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.kvt.domain.AssetStructureList;
import com.muyu.kvt.domain.DataType;
import com.muyu.kvt.domain.Kvt;
import com.muyu.kvt.domain.Tables;
import com.muyu.kvt.domain.req.AssetStructureResponse;
import com.muyu.kvt.domain.req.KvtEditReq;
import com.muyu.kvt.domain.req.KvtQueryReq;
import com.muyu.kvt.domain.req.KvtSaveReq;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import com.muyu.kvt.service.KvtService;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;

/**
 * kvt
Controller
 *
 * @author muyu
 * @date 2024-04-20
 */
@Api(tags = "kvt")
@RestController
@RequestMapping("/kvt")
public class KvtController extends BaseController {
    @Autowired
    private KvtService kvtService;

    /**
     * 查询kvt列表
     */
    @ApiOperation("获取kvt列表")
    @RequiresPermissions("kvt:kvt:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Kvt>> list(KvtQueryReq kvtQueryReq) {
        startPage();
        List<Kvt> list = kvtService.list(Kvt.queryBuild(kvtQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出kvt列表
     */
    @ApiOperation("导出kvt列表")
    @RequiresPermissions("kvt:kvt:export")
    @Log(title = "kvt", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Kvt kvt) {
        List<Kvt> list = kvtService.list(kvt);
        ExcelUtil<Kvt> util = new ExcelUtil<Kvt>(Kvt.class);
        util.exportExcel(response, list, "kvt数据");
    }

    /**
     * 获取kvt详细信息
     */
    @ApiOperation("获取kvt详细信息")
    @RequiresPermissions("kvt:kvt:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Kvt> getInfo(@PathVariable("id") Long id) {
        return Result.success(kvtService.getById(id));
    }

    /**
     * 新增kvt

     */
    @RequiresPermissions("kvt:kvt:add")
    @Log(title = "kvt ", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增kvt ")
    public Result<String> add(@RequestBody KvtSaveReq kvtSaveReq) {
        return toAjax(kvtService.save(Kvt.saveBuild(kvtSaveReq)));
    }

    /**
     * 修改kvt

     */
    @RequiresPermissions("kvt:kvt:edit")
    @Log(title = "kvt ", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改kvt")
    public Result<String> edit(@PathVariable Long id, @RequestBody KvtEditReq kvtEditReq) {
        return toAjax(kvtService.updateById(Kvt.editBuild(id,kvtEditReq)));
    }

    /**
     * 删除kvt

     */
    @RequiresPermissions("kvt:kvt:remove")
    @Log(title = "kvt ", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除kvt")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(kvtService.removeBatchByIds(ids));
    }

    /**
     * 测试连接
     */
    @PostMapping("/connectionTest")
    public Result connectionTest(@RequestBody Kvt kvt) throws SQLException, ClassNotFoundException {
       boolean test= kvtService.connectionTest(kvt);
        if (test){
            return Result.success("测试成功");
        }else {
            return Result.error("测试失败");
        }
    }


    @PostMapping("/dataTypeList")
    public Result<List<DataType>> dataTypeList(){
        List<DataType> dataTypeList=kvtService.dataTypeList();
        return  Result.success(dataTypeList);

    }

    @PostMapping("/synchronizationAdd")
    public Result synchronizationAdd (@RequestBody Kvt kvt) throws SQLException, ClassNotFoundException {
        kvtService.synchronizationAdd(kvt);
           return  Result.success();

    }

//    @PostMapping("/selectName")
//    public Result<List<String>> listResult(@RequestParam String name) throws SQLException, ClassNotFoundException {
//      Kvt kvt=   kvtService.listResult(name);
//       List<String> list= kvtService.kvtList(kvt);
//       return Result.success(list);
//    }
//
//      @PostMapping("/assetStructureResponse")
//    public Result<List<AssetStructureResponse>> assetStructureResponse( ) throws SQLException, ClassNotFoundException {
//          List<AssetStructureResponse> assetStructureList= kvtService.assetStructureResponse();
//
//       return Result.success(assetStructureList)  ;
//    }

}
