package com.muyu.kvt.service.impl;

import java.sql.*;
import java.util.ArrayList;
import java.util.List;

import com.muyu.common.core.utils.ObjUtils;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.kvt.domain.AssetStructureList;
import com.muyu.kvt.domain.ChildrenList;
import com.muyu.kvt.domain.DataType;
import com.muyu.kvt.domain.Kvt;
import com.muyu.kvt.domain.req.AssetStructureResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import com.muyu.kvt.mapper.KvtMapper;
import com.muyu.kvt.service.KvtService;
/**
 * kvt
Service业务层处理
 *
 * @author muyu
 * @date 2024-04-20
 */
@Slf4j
@Service
public class KvtServiceImpl extends ServiceImpl<KvtMapper, Kvt> implements KvtService {

    /**
     * 查询kvt列表
     *
     * @param kvt kvt
     * @return kvt

     */
    @Override
    public List<Kvt> list(Kvt kvt) {
        LambdaQueryWrapper<Kvt> queryWrapper = new LambdaQueryWrapper<>();


        if (ObjUtils.notNull(kvt.getName())){
            queryWrapper.like(Kvt::getName, kvt.getName());
        }

        if (ObjUtils.notNull(kvt.getSystemName())){
            queryWrapper.like(Kvt::getSystemName, kvt.getSystemName());
        }

        if (ObjUtils.notNull(kvt.getType())){
            queryWrapper.eq(Kvt::getType, kvt.getType());
        }

        if (ObjUtils.notNull(kvt.getHost())){
            queryWrapper.eq(Kvt::getHost, kvt.getHost());
        }

        if (ObjUtils.notNull(kvt.getPort())){
            queryWrapper.eq(Kvt::getPort, kvt.getPort());
        }

        if (ObjUtils.notNull(kvt.getDatabaseName())){
            queryWrapper.like(Kvt::getDatabaseName, kvt.getDatabaseName());
        }

        if (ObjUtils.notNull(kvt.getConnectionParam())){
            queryWrapper.eq(Kvt::getConnectionParam, kvt.getConnectionParam());
        }

        if (ObjUtils.notNull(kvt.getInitNum())){
            queryWrapper.eq(Kvt::getInitNum, kvt.getInitNum());
        }

        if (ObjUtils.notNull(kvt.getMaxNum())){
            queryWrapper.eq(Kvt::getMaxNum, kvt.getMaxNum());
        }

        if (ObjUtils.notNull(kvt.getMaxWaitTime())){
            queryWrapper.eq(Kvt::getMaxWaitTime, kvt.getMaxWaitTime());
        }

        if (ObjUtils.notNull(kvt.getMaxWaitSize())){
            queryWrapper.eq(Kvt::getMaxWaitSize, kvt.getMaxWaitSize());
        }





        return list(queryWrapper);
    }

    @Override
    public boolean connectionTest(Kvt kvt) throws ClassNotFoundException, SQLException {
        String user = kvt.getUsername();
        String password =  kvt.getPassword();
        String jdbcDriver = "com.mysql.cj.jdbc.Driver";
        String jdbcUrl = "jdbc:mysql://"+kvt.getHost()+":"+kvt.getPort()+"/"+kvt.getDatabaseName()+"?"+kvt.getConnectionParam();
        Class.forName(jdbcDriver);
        Connection connection = DriverManager.getConnection(jdbcUrl, user, password);
        if (connection==null){
            return false;
        }
        return true;
    }

    @Override
    public List<DataType> dataTypeList() {
        return baseMapper.dataTypeList();
    }

    @Override
    public Kvt listResult(String name) {
        return baseMapper.findName(name);
    }

//    @Override
//    public List<AssetStructureList> assetStructureList() throws ClassNotFoundException, SQLException {
//        List<Kvt> list = list();
//        for (Kvt kvt : list) {
//            String user = kvt.getUsername();
//            String password = kvt.getPassword();
//            String jdbcDriver = "com.mysql.cj.jdbc.Driver";
//            String jdbcUrl = "jdbc:mysql://" + kvt.getHost() + ":" + kvt.getPort() + "/" + kvt.getDatabaseName() + "?" + kvt.getConnectionParam();
//            Class.forName(jdbcDriver);
//            Connection connection = DriverManager.getConnection(jdbcUrl, user, password);
//            if (connection == null) {
//                throw new RuntimeException("连接失败");
//            }
//
//            AssetStructureList assetStructureList = new AssetStructureList();
//            assetStructureList.setName(kvt.getName());
//            assetStructureList.setType(kvt.getType());
//            assetStructureList.setSystemName(kvt.getSystemName());
//            assetStructureList.setDatabaseName(kvt.getDatabaseName());
//
//
//        }
//        AssetStructureList assetStructureList = new AssetStructureList();
//        return  assetStructureList;
//
//    }

    @Override
    public List<AssetStructureResponse> assetStructureResponse() throws ClassNotFoundException, SQLException {
        List<Kvt> list = list();
        for (Kvt kvt : list) {
            String user = kvt.getUsername();
            String password =  kvt.getPassword();
            String jdbcDriver = "com.mysql.cj.jdbc.Driver";
            String jdbcUrl = "jdbc:mysql://"+kvt.getHost()+":"+kvt.getPort()+"/"+kvt.getDatabaseName()+"?"+kvt.getConnectionParam();
            Class.forName(jdbcDriver);
            Connection connection = DriverManager.getConnection(jdbcUrl, user, password);
            if (connection==null){
                throw  new RuntimeException("连接失败");
            }

            AssetStructureList assetStructureList = new AssetStructureList();
            assetStructureList.setName(kvt.getName());
            assetStructureList.setType(kvt.getType());
            assetStructureList.setSystemName(kvt.getSystemName());
            assetStructureList.setDatabaseName(kvt.getDatabaseName());
            ArrayList<AssetStructureList> assetStructureLists = new ArrayList<>();
            assetStructureLists.add(assetStructureList);

            Statement statement = connection.createStatement();
            String sql = "SHOW TABLES FROM "+kvt.getDatabaseName(); // 查询数据库中的所有表
            ResultSet resultSet = statement.executeQuery(sql);
            ResultSetMetaData metaData = resultSet.getMetaData();
            int columnCount = metaData.getColumnCount();


            List<ChildrenList> childrenLists = new ArrayList<>();
            List<AssetStructureResponse> assetStructureResponses = new ArrayList<>();

            // 遍历结果集的列，获取表名
            while (resultSet.next()) {
                for (int i = 1; i <= columnCount; i++) {
                    ChildrenList childrenList = new ChildrenList();
                    String tableName = resultSet.getString(i);



                    String remark = "SELECT table_name, table_comment FROM information_schema.tables WHERE table_schema = '" + kvt.getDatabaseName() + "' AND table_name = '" + tableName + "'";
                    System.out.println(remark);
                    ResultSet resultSet22 = statement.executeQuery(remark);
                    if (resultSet22.next()) {
                        String tableComment = resultSet22.getString(tableName);
                        System.out.println("表备注：" + tableComment);
                        System.out.println("seggredhjrdfg"+tableComment);
                        childrenList.setName(tableComment);
                    }


                    String count = "SELECT COUNT(*) AS total_records FROM "+tableName; // 查询数据库中的所有表
                    ResultSet resultSet11 = statement.executeQuery(count);
                    if (resultSet11.next()){
                        int totalRecords = resultSet11.getInt(tableName);
                        childrenList.setDataTotal(totalRecords);
                    }


                    childrenList.setAs(tableName);


                    childrenList.setType(kvt.getType());
                    childrenLists.add(childrenList);
                }
            }
            AssetStructureResponse build = AssetStructureResponse.builder()
                    .assetStructureLists(assetStructureLists)
                    .childrenLists(childrenLists)
                    .build();
            assetStructureResponses.add(build );
        }

        return assetStructureResponse();
    }

    @Override
    public void synchronizationAdd(Kvt kvt) throws SQLException, ClassNotFoundException {
        boolean b = this.connectionTest(kvt);
        if (b){
            baseMapper.synchronizationAdd(kvt);
        }else {

            throw new RuntimeException("同步失败");
        }

    }

//    @Override
//    public List<String> kvtList(Kvt kvt) {
//        String user = kvt.getUsername();
//        String password =  kvt.getPassword();
//        String jdbcDriver = "com.mysql.cj.jdbc.Driver";
//        String jdbcUrl = "jdbc:mysql://" + kvt.getHost() + ":" + kvt.getPort() + "/" + kvt.getDatabaseName() + "?" + kvt.getConnectionParam();
//
//        Connection connection = null;
//        List<String> tables = new ArrayList<>();
//
//        try {
//            Class.forName(jdbcDriver);
//            connection = DriverManager.getConnection(jdbcUrl, user, password);
//            Statement statement = connection.createStatement();
//            String sql = "SHOW TABLES"; // 查询数据库中的所有表
//            ResultSet resultSet = statement.executeQuery(sql);
//            ResultSetMetaData metaData = resultSet.getMetaData();
//            int columnCount = metaData.getColumnCount();
//
//            // 遍历结果集的列，获取表名
//            while (resultSet.next()) {
//                for (int i = 1; i <= columnCount; i++) {
//                    String tableName = resultSet.getString(i);
//                    tables.add(tableName);
//                    System.out.println("表名：" + tableName);
//                }
//            }
//        } catch (ClassNotFoundException e) {
//            e.printStackTrace();
//        } catch (SQLException e) {
//            e.printStackTrace();
//        } finally {
//            // 关闭连接
//            if (connection != null) {
//                try {
//                    connection.close();
//                } catch (SQLException e) {
//                    e.printStackTrace();
//                }
//            }
//        }
//
//        return tables;
//    }
}
